@@ -69,7 +69,7 @@ static int kldap_timeout_value(int msecs, int elapsed)
     return timeout < 0 ? 0 : timeout;
 }
 
-class LdapOperation::LdapOperationPrivate
+class Q_DECL_HIDDEN LdapOperation::LdapOperationPrivate
 {
 public:
     LdapOperationPrivate();
@@ -171,6 +171,7 @@ QByteArray LdapOperation::serverCred() const
 }
 
 LdapOperation::LdapOperationPrivate::LdapOperationPrivate()
+    : mConnection(Q_NULLPTR)
 {
 }
 
